==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/id-ID/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Aksesoris Kembali',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Aset Kembali',
    'Asset_Checkout_Notification' => 'Kembali-kan aset',
    'Confirm_Accessory_Checkin' => 'Konfirmasi check-in Aksesoris',
    'Confirm_Asset_Checkin' => 'Konfirmasi check-in Aset',
    'Confirm_accessory_delivery' => 'Konfirmasi pengiriman Aksesoris',
    'Confirm_asset_delivery' => 'Konfirmasi pengiriman Aset',
    'Confirm_consumable_delivery' => 'Konfirmasi pengiriman Habis Pakai',
    'Confirm_license_delivery' => 'Konfirmasi pengiriman Lisensi',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Hari',
    'Expected_Checkin_Date' => 'Aset yang check out untuk Anda akan check in kembali pada :date',
    'Expected_Checkin_Notification' => 'Pengingat: :name mendekati batas waktu check-in [Dikembalikan]',
    'Expected_Checkin_Report' => 'Laporan check-in aset yang diharapkan',
    'Expiring_Assets_Report' => 'Laporan Aktiva Kedaluwarsa',
    'Expiring_Licenses_Report' => 'Laporan Lisensi yang Berakhir',
    'Item_Request_Canceled' => 'Permintaan Barang Dibatalkan',
    'Item_Requested' => 'Barang yang diminta',
    'License_Checkin_Notification' => 'Lisensi Kembali',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Laporan Inventaris Rendah',
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di situs web',
    'a_user_requested' => 'Pengguna telah meminta item di situs web',
    'acceptance_asset_accepted' => 'Pengguna telah menerima',
    'acceptance_asset_declined' => 'Pengguna telah menolak',
    'accessory_name' => 'Nama Aksesori:',
    'additional_notes' => 'Catatan Tambahan:',
    'admin_has_created' => 'Administrator telah membuat akun untuk Anda di: situs web web.',
    'asset' => 'Aset:',
    'asset_name' => 'Nama Aset:',
    'asset_requested' => 'Permintaan aset',
    'asset_tag' => 'Tag Aset',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Salam Hormat,',
    'canceled' => 'Dibatalkan:',
    'checkin_date' => 'Tanggal Checkin:',
    'checkout_date' => 'Tanggal keluar:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aset tersebut.',
    'click_to_confirm' => 'Silahkan klik pada link berikut untuk mengkonfirmasi: akun web Anda:',
    'current_QTY' => 'QTY saat ini',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tanggal Checkin yang Diharapkan:',
    'expires' => 'Kadaluarsa',
    'hello' => 'Halo',
    'hi' => 'Hai',
    'i_have_read' => 'Saya telah membaca dan menyetujui persyaratan penggunaan, dan telah menerima barang ini.',
    'inventory_report' => 'Laporan Inventori',
    'item' => 'Barang:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.|Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.',
    'link_to_update_password' => 'Silahkan klik pada link berikut untuk mengupdate: password web anda:',
    'login' => 'Login:',
    'login_first_admin' => 'Login ke instalasi Snipe-IT baru Anda dengan menggunakan kredensial di bawah ini:',
    'low_inventory_alert' => 'Ada :count item yang di bawah minimum persediaan atau akan segera habis.|Ada :count item yang di bawah minimum persediaan atau akan segera habis.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa berdasarkan nama Anda, rinciannya ada di bawah.',
    'notes' => 'Catatan',
    'password' => 'Password:',
    'password_reset' => 'Reset Password',
    'read_the_terms' => 'Silahkan baca syarat penggunaan di bawah ini.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Diminta:',
    'reset_link' => 'Tautan Reset Sandi Anda',
    'reset_password' => 'Klik di sini untuk mengatur ulang kata sandi Anda:',
    'rights_reserved' => 'Hak cipta di lindungi undang-undang.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Pemasok',
    'tag' => 'Menandai',
    'test_email' => 'Uji Email dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Snipe-IT Asset Management System. Jika Anda mendapatkan ini, surat bekerja :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'to_reset' => 'Untuk mereset password web anda, lengkapi form ini:',
    'type' => 'Mengetik',
    'upcoming-audits' => 'Ada :count aset yang akan diaudit dalam :threshold hari.|Ada :count aset yang akan diaudit dalam :threshold hari.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat Datang di: web!',
    'your_assets' => 'Lihat Aset Anda',
    'your_credentials' => 'Kredensial Snipe-IT Anda',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/id-ID/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Aksesoris Kembali',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Aset Kembali',
    'Asset_Checkout_Notification' => 'Kembali-kan aset',
    'Confirm_Accessory_Checkin' => 'Konfirmasi check-in Aksesoris',
    'Confirm_Asset_Checkin' => 'Konfirmasi check-in Aset',
    'Confirm_accessory_delivery' => 'Konfirmasi pengiriman Aksesoris',
    'Confirm_asset_delivery' => 'Konfirmasi pengiriman Aset',
    'Confirm_consumable_delivery' => 'Konfirmasi pengiriman Habis Pakai',
    'Confirm_license_delivery' => 'Konfirmasi pengiriman Lisensi',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Hari',
    'Expected_Checkin_Date' => 'Aset yang check out untuk Anda akan check in kembali pada :date',
    'Expected_Checkin_Notification' => 'Pengingat: :name mendekati batas waktu check-in [Dikembalikan]',
    'Expected_Checkin_Report' => 'Laporan check-in aset yang diharapkan',
    'Expiring_Assets_Report' => 'Laporan Aktiva Kedaluwarsa',
    'Expiring_Licenses_Report' => 'Laporan Lisensi yang Berakhir',
    'Item_Request_Canceled' => 'Permintaan Barang Dibatalkan',
    'Item_Requested' => 'Barang yang diminta',
    'License_Checkin_Notification' => 'Lisensi Kembali',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Laporan Inventaris Rendah',
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di situs web',
    'a_user_requested' => 'Pengguna telah meminta item di situs web',
    'acceptance_asset_accepted' => 'Pengguna telah menerima',
    'acceptance_asset_declined' => 'Pengguna telah menolak',
    'accessory_name' => 'Nama Aksesori',
    'additional_notes' => 'Catatan Tambahan',
    'admin_has_created' => 'Administrator telah membuat akun untuk Anda di: situs web web.',
    'asset' => 'Aset',
    'asset_name' => 'Nama Aset',
    'asset_requested' => 'Permintaan aset',
    'asset_tag' => 'Tag Aset',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Salam Hormat,',
    'canceled' => 'Dibatalkan',
    'checkin_date' => 'Tanggal Pengembalian',
    'checkout_date' => 'Tanggal Pemberian',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aset tersebut.',
    'click_to_confirm' => 'Silahkan klik pada link berikut untuk mengkonfirmasi: akun web Anda:',
    'current_QTY' => 'QTY saat ini',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tanggal pengembalian diharapkan diterima',
    'expires' => 'Kadaluarsa',
    'hello' => 'Halo',
    'hi' => 'Hai',
    'i_have_read' => 'Saya telah membaca dan menyetujui persyaratan penggunaan, dan telah menerima barang ini.',
    'inventory_report' => 'Laporan Inventori',
    'item' => 'Item',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.|Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.',
    'link_to_update_password' => 'Silahkan klik pada link berikut untuk mengupdate: password web anda:',
    'login' => 'Login:',
    'login_first_admin' => 'Login ke instalasi Snipe-IT baru Anda dengan menggunakan kredensial di bawah ini:',
    'low_inventory_alert' => 'Ada :count item yang di bawah minimum persediaan atau akan segera habis.|Ada :count item yang di bawah minimum persediaan atau akan segera habis.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa berdasarkan nama Anda, rinciannya ada di bawah.',
    'notes' => 'Catatan',
    'password' => 'Kata sandi',
    'password_reset' => 'Reset Password',
    'read_the_terms' => 'Silahkan baca syarat penggunaan di bawah ini.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Diminta',
    'reset_link' => 'Tautan Reset Sandi Anda',
    'reset_password' => 'Klik di sini untuk mengatur ulang kata sandi Anda:',
    'rights_reserved' => 'Hak cipta di lindungi undang-undang.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Pemasok',
    'tag' => 'Menandai',
    'test_email' => 'Uji Email dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Snipe-IT Asset Management System. Jika Anda mendapatkan ini, surat bekerja :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'to_reset' => 'Untuk mereset password web anda, lengkapi form ini:',
    'type' => 'Mengetik',
    'upcoming-audits' => 'Ada :count aset yang akan diaudit dalam :threshold hari.|Ada :count aset yang akan diaudit dalam :threshold hari.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat Datang di: web!',
    'your_assets' => 'Lihat Aset Anda',
    'your_credentials' => 'Kredensial Snipe-IT Anda',
    'mail_sent' => 'Mail sent successfully!',
];
